#
# spec file for package libkdecoration2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global sover 5
%global private_sover 10
%define lname           libkdecorations2-%{sover}
%define lname_private   libkdecorations2private%{private_sover}
%bcond_without released
Name:           libkdecoration2
Version:        5.27.11
Release:        1.3
Summary:        KDE's window decorations library
License:        GPL-2.0-or-later
Group:          System/GUI/KDE
URL:            http://www.kde.org
Source:         https://download.kde.org/stable/plasma/%{version}/kdecoration-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/kdecoration-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
BuildRequires:  cmake >= 3.16
BuildRequires:  extra-cmake-modules >= 5.98.0
BuildRequires:  kf5-filesystem
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(Qt5Core) >= 5.15.0
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Test)

%description
Plugin based library to create window decorations.

%package devel
Summary:        KDE's window decorations library (development package)
Group:          Development/Libraries/C and C++
Requires:       %{lname_private} = %{version}
Requires:       %{lname} = %{version}
Requires:       cmake(Qt5Gui)
Obsoletes:      libkdecorations-devel < 5.2

%description devel
Development files belonging to kdecoration,
plugin based library to create window decorations.

%package -n %{lname}
Summary:        KDE's window decorations library
Group:          System/GUI/KDE
Obsoletes:      libkdecorations5 < 5.2
Recommends:     %{lname}-lang

%description -n %{lname}
Plugin based library to create window decorations.

%package -n %{lname_private}
Summary:        KDE's window decorations library
Group:          System/GUI/KDE

%description -n %{lname_private}
Plugin based library to create window decorations.

%lang_package -n %{lname}

%prep
%autosetup -p1 -n kdecoration-%{version}

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build

%find_lang %{name} --all-name

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig
%post -n %{lname_private} -p /sbin/ldconfig
%postun -n %{lname_private} -p /sbin/ldconfig

%files -n %{lname}
%license LICENSES/*
%{_kf5_libdir}/libkdecorations2.so.%{sover}
%{_kf5_libdir}/libkdecorations2.so.%{sover}.*

%files -n %{lname_private}
%license LICENSES/*
%{_kf5_libdir}/libkdecorations2private.so.%{private_sover}
%{_kf5_libdir}/libkdecorations2private.so.%{sover}.*

%files devel
%license LICENSES/*
%{_kf5_libdir}/libkdecorations2.so
%{_kf5_libdir}/libkdecorations2private.so
%{_kf5_libdir}/cmake/KDecoration2/
%{_kf5_prefix}/include/KDecoration2/
%{_kf5_includedir}/

%files -n %{lname}-lang -f %{name}.lang
%license LICENSES/*

%changelog
* Wed Mar  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.11:
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.11
- Changes since 5.27.10:
  * Port to new CI syntax
* Wed Dec  6 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.10
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.10
- No code changes since 5.27.9
* Tue Oct 24 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.9
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.9
- No code changes since 5.27.8
* Tue Sep 12 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.8
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.8
- No code changes since 5.27.7
* Tue Aug  1 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.7
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.7
- No code changes since 5.27.6
* Tue Jun 20 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.6
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.6
- No code changes since 5.27.5
* Tue May  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.5
- No code changes since 5.27.4
* Tue Apr  4 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.4
- No code changes since 5.27.3
* Tue Mar 14 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.3
- No code changes since 5.27.2
* Tue Feb 28 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.2
- No code changes since 5.27.1
* Tue Feb 21 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.1
- No code changes since 5.27.0
* Thu Feb  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.0
- No code changes since 5.26.90
* Thu Jan 19 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.90
- Changes since 5.26.5:
  * port all headers to pragma once
  * Add DecoratedClient::windowClass()
  * Floor mouse positions rather than rounding
* Wed Jan  4 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.5
- No code changes since 5.26.4
* Tue Nov 29 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.4
- No code changes since 5.26.3
* Tue Nov  8 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.3
- No code changes since 5.26.2
* Wed Oct 26 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.2
- Changes since 5.26.1:
  * Floor mouse positions rather than rounding
* Tue Oct 18 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.1
- No code changes since 5.26.0
* Thu Oct  6 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.0
- No code changes since 5.25.90
* Thu Sep 15 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.90
- Changes since 5.25.5:
  * Add FreeBSD Qt6 CI support
  * Add missing license file
  * Request passing unit tests on Linux and BSD
  * Use QFETCH + QCOMPARE rather than QTEST for container sizes
  * Remove duplicate headers between cpp/h
* Tue Sep  6 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.5
- No code changes since 5.25.4
* Tue Aug  2 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.4
- No code changes since 5.25.3
* Tue Jul 12 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.3
- No code changes since 5.25.2
* Tue Jun 28 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.2
- No code changes since 5.25.1
* Tue Jun 21 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.1
- No code changes since 5.25.0
* Thu Jun  9 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.0
- No code changes since 5.24.90
* Thu May 19 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.90
- Changes since 5.24.5:
  * Add RtL support (kde#432390)
  * Hide tooltip when pressing button
  * decoration:add blurregion property
  * Add KF6 build support and CI
* Tue May  3 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.5
- No code changes since 5.24.4
* Tue Mar 29 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.4
- Changes since 5.24.3:
  * Add RtL support (kde#432390)
* Tue Mar  8 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.3
- No code changes since 5.24.2
* Tue Feb 22 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.2
- Changes since 5.24.1:
  * Hide tooltip when pressing button
* Tue Feb 15 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.1
- No code changes since 5.24.0
* Sat Feb  5 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.0
- No code changes since 5.23.90
* Thu Jan 13 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.90
- Changes since 5.23.5:
  * Port away from deprecated QWeakPointer::data()
  * Source code changes to enable building against Qt6
  * Fix warning
  * Add FreeBSD CI
  * Add Linux CI
  * Add .kde-ci.yml
  * Use QSharedData for DecorationThemeMetaDataPrivate class
  * Add new DecorationThemeProvider class
* Tue Jan  4 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.5
- No code changes since 5.23.4
* Tue Nov 30 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.4
- No code changes since 5.23.3
* Tue Nov  9 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.3
- No code changes since 5.23.2
* Tue Oct 26 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.2
- No code changes since 5.23.1
* Tue Oct 19 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.1
- No code changes since 5.23.0
* Thu Oct  7 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.0
- No code changes since 5.22.90
- Add new key + signature to plasma.keyring
* Thu Sep 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.90
- Changes since 5.22.5:
  * Explicitly set KDE_COMPILERSETTINGS_LEVEL
  * Add kdecoration to plasma group for documentation purpose
  * Build KDecoration with -DQT_NO_KEYWORDS
  * Replace emit with Q_EMIT
  * Introduce Decoration::damaged signal
* Wed Sep 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop the unneeded baselibs.conf.
* Tue Aug 31 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.5
- No code changes since 5.22.4
* Tue Jul 27 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.4
- No code changes since 5.22.3
* Tue Jul  6 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.3
- No code changes since 5.22.2.1
* Wed Jun 23 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.2.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.2
- No code changes since 5.22.1
* Tue Jun 15 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.1
- No code changes since 5.22.0
* Thu Jun  3 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.0
- No code changes since 5.21.90
* Thu May 13 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.90
- Changes since 5.21.5:
  * Migrate to KDECompilerSettings
  * Use Q_EMIT to make it compile against kf5.82
  * Port away from ECMSetupVersion's deprecated *_VERSION_STRING CMake variable
  * Use clearer text for "Menu" decoration button
  * Improve tooltips for "keep above"/"keep below" buttons (kde#435292)
  * Add .git-blame-ignore-revs file
  * Run clang-format
  * Add clang-format pre-commit hook
  * Add trailing comma to enums
  * Raise minimum CMake version to 3.16
  * Use versionless Qt cmake target
* Tue May  4 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.5
- No code changes since 5.21.4
* Tue Apr  6 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.4
- No code changes since 5.21.3
* Tue Mar 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.3
- No code changes since 5.21.2
* Tue Mar  2 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.2
- No code changes since 5.21.1
* Tue Feb 23 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.1
- No code changes since 5.21.0
* Thu Feb 11 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.0
- No code changes since 5.20.90
* Thu Jan 21 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/20.90/
- Changes since 5.20.5:
  * Use non-deprecated KDE_INSTALL_CMAKEPACKAGEDIR
  * Add .gitignore file to ignore generated .clang-format
  * bump .so number of kdecorations2private
  * Restore ABI of libkdecorations2.so
  * Add a QRect to requestShowWindowMenu
  * If include is define in .h remove it if it's defined in .cpp too (scripted)
* Tue Jan  5 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.5
- No code changes since 5.20.4
* Tue Dec  1 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.4
- No code changes since 5.20.3
* Wed Nov 11 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.3
- No code changes since 5.20.2
* Tue Oct 27 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.2
- No code changes since 5.20.1
* Tue Oct 20 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.1
- No code changes since 5.20.0
* Thu Oct  8 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.0
- No code changes since 5.19.90
- Use only versioned obsoletes
* Thu Sep 17 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.90
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.90
- Changes since 5.19.5:
  * Remove explicit ECM_KDE_MODULE_DIR
  * Convert copyright statements to SPDX expressions
* Tue Sep  1 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.5
- No code changes since 5.19.4
* Tue Jul 28 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.4
- No code changes since 5.19.3
* Tue Jul  7 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.3
- No code changes since 5.19.2
* Tue Jun 23 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.2
- No code changes since 5.19.1
* Tue Jun 16 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.19.1.php
- No code changes since 5.19.0
* Thu Jun  4 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.19.0.php
- Changes since 5.18.90:
  * Remove is-git-checkout condition for applying deprecated API visibility
  * Only deprecate up to target frameworks
* Thu May 14 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.90.php
- Changes since 5.18.5:
  * bump to require Qt 5.14
  * Only deprecate up to target frameworks
  * Improve metainfo.yaml: mention FreeBSD support, drop tier mention, indent
  * Use K_DOXYGEN instead of deprecated DOXYGEN_SHOULD_SKIP_THIS
  * Enable publication of API dox on api.kde.org
* Tue May  5 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.5.php
- No code changes since 5.18.4.1
* Tue Mar 31 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.4.1:
  * Version fixed
* Tue Mar 31 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.4.php
- No code changes since 5.18.3
* Tue Mar 10 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.3.php
- Changes since 5.18.2:
  * Only deprecate up to target frameworks
* Tue Feb 25 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.2.php
- No code changes since 5.18.1
* Tue Feb 18 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.1.php
- No code changes since 5.18.0
* Thu Feb  6 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.0.php
- Changes since 5.17.90:
  * Add a convenience property to retrieve the size of the decorated client
* Thu Jan 23 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build
* Thu Jan 16 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.90.php
- Changes since 5.17.5:
  * KF5_MIN_VERSION for plasma 5.18 is KF5 5.66.0
  * Fix git builds against Qt 5.14
  * Fixup deprecated use of QWeakPointer::data
  * Add KDEClangFormat cmake support
  * Port old style connects in QSignalSpy
* Tue Jan  7 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.5.php
- No code changes since 5.17.4
* Wed Dec  4 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.4.php
- No code changes since 5.17.3
* Tue Nov 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.3.php
- No code changes since 5.17.2
* Tue Oct 29 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.2.php
- No code changes since 5.17.1
* Tue Oct 22 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.1.php
- No code changes since 5.17.0
* Thu Oct 10 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.0.php
- No code changes since 5.16.90
* Thu Sep 19 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.90.php
- Changes since 5.16.5:
  * update to latest kf5 dependency
* Tue Sep  3 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.5.php
- No code changes since 5.16.4
* Tue Jul 30 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.4.php
- No code changes since 5.16.3
* Tue Jul  9 2019 fabian@ritter-vogt.de
- Update to 5.16.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.3.php
- No code changes since 5.16.2
* Tue Jun 25 2019 fabian@ritter-vogt.de
- Update to 5.16.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.2.php
- No code changes since 5.16.1
* Tue Jun 18 2019 fabian@ritter-vogt.de
- Update to 5.16.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.1.php
- No code changes since 5.16.0
* Thu Jun  6 2019 fabian@ritter-vogt.de
- Update to 5.16.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.0.php
- No code changes since 5.15.90
* Thu May 16 2019 fabian@ritter-vogt.de
- Update to 5.15.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.90.php
- Changes since 5.15.5:
  * bump Qt version to 5.12 as agreed at start of cycle
* Tue May  7 2019 fabian@ritter-vogt.de
- Update to 5.15.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.5.php
- No code changes since 5.15.4
* Tue Apr  2 2019 fabian@ritter-vogt.de
- Update to 5.15.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.4.php
- No code changes since 5.15.3
* Tue Mar 12 2019 fabian@ritter-vogt.de
- Update to 5.15.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.3.php
- No code changes since 5.15.2
* Tue Feb 26 2019 fabian@ritter-vogt.de
- Update to 5.15.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.2.php
- No code changes since 5.15.1
* Tue Feb 19 2019 fabian@ritter-vogt.de
- Update to 5.15.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.1.php
- No code changes since 5.15.0
* Thu Feb  7 2019 fabian@ritter-vogt.de
- Update to 5.15.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.0.php
- No code changes since 5.14.90
* Thu Jan 17 2019 fabian@ritter-vogt.de
- Update to 5.14.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.90.php
- Changes since 5.14.5:
  * bump KF5 dependency to required 5.54 as agreed at start of Plasma 5.15 cycle
* Tue Jan  8 2019 fabian@ritter-vogt.de
- Update to 5.14.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.5.php
- No code changes since 5.14.4
* Wed Nov 28 2018 fabian@ritter-vogt.de
- Update to 5.14.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.4.php
- No code changes since 5.14.3
* Tue Nov  6 2018 fabian@ritter-vogt.de
- Add David Edmundson's key to plasma.keyring
- Update to 5.14.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.3.php
- No code changes since 5.14.2
* Tue Oct 23 2018 fabian@ritter-vogt.de
- Update to 5.14.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.2.php
- No code changes since 5.14.1
* Tue Oct 16 2018 fabian@ritter-vogt.de
- Update to 5.14.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.1.php
- No code changes since 5.14.0
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.14.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.0.php
- No code changes since 5.13.90
* Sat Sep 15 2018 fabian@ritter-vogt.de
- Add tarball signature and keyring containing keys of release managers
  Jonathan Riddell and Bhushan Shah
* Thu Sep 13 2018 fabian@ritter-vogt.de
- Update to 5.13.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.90.php
- Changes since 5.13.5:
  * QT_MIN_VERSIONS is Qt 5.11 for Plasma 5.14. Agreed at kickoff meeting.  Set everywhere for clearity and consistency.
  * Check against QRect whether pointer is inside DecorationButton
* Tue Sep  4 2018 fabian@ritter-vogt.de
- Update to 5.13.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.5.php
- Changes since 5.13.4:
  * None
* Tue Jul 31 2018 fabian@ritter-vogt.de
- Update to 5.13.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.4.php
- Changes since 5.13.3:
  * None
* Tue Jul 10 2018 fabian@ritter-vogt.de
- Update to 5.13.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.3.php
- Changes since 5.13.2:
  * None
* Tue Jun 26 2018 fabian@ritter-vogt.de
- Update to 5.13.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.2.php
- Changes since 5.13.1:
  * None
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.13.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.1.php
- Changes since 5.13.0:
  * None
* Thu Jun 14 2018 wbauer@tmo.at
- Recommend lang package
* Thu Jun  7 2018 fabian@ritter-vogt.de
- Update to 5.13.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.0.php
- Changes since 5.12.90:
  * None
* Tue May 29 2018 fabian@ritter-vogt.de
- %%lang_package -n %%{lname}
- Run spec-cleaner
* Sat May 19 2018 fabian@ritter-vogt.de
- Update to 5.12.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.90.php
- Changes since 5.12.5:
  * Do not leak symbols of pimpl classes, protect with Q_DECL_HIDDEN
  * Use non-deprecated KDEInstallDirs variables
  * Use override
  * Group cmake macro includes as done in other plasma repos
  * Use KF5_MIN_VERSION also for ECM, now that it's part of KF
  * Use add_test signature where target command gets resolved to binary path
  * Drop ECMPackageConfigHelpers for CMakePackageConfigHelpers
  * Require KDE Frameworks 5.42 and Qt 5.9
  * Bump min cmake version to 3.0, move cmake_minimum_required to begin
  * Make the messages translatable
  * Build test/autotest if BUILD_TESTING is defined
  * Tooltips (kde#383040)
* Wed May  2 2018 fabian@ritter-vogt.de
- Update to 5.12.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.5.php
- Changes since 5.12.4:
  * None
* Tue Mar 27 2018 fabian@ritter-vogt.de
- Update to 5.12.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.4.php
- Changes since 5.12.3:
  * None
* Tue Mar  6 2018 fabian@ritter-vogt.de
- Update to 5.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.3.php
- Changes since 5.12.2:
  * None
* Wed Feb 21 2018 lbeltrame@kde.org
- Update to 5.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.2.php
- Changes since 5.12.1:
  * None
* Tue Feb 13 2018 fabian@ritter-vogt.de
- Update to 5.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.1.php
- Changes since 5.12.0:
  * None
* Fri Feb  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.0.php
- Changes since 5.11.95:
  * None
* Mon Jan 15 2018 fabian@ritter-vogt.de
- Update to 5.11.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.95.php
- Changes since 5.11.5:
  * Remove obsolete reviewboardrc file
* Tue Jan  2 2018 fabian@ritter-vogt.de
- Update to 5.11.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.5.php
- Changes since 5.11.4:
  * None
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.11.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.4.php
- Changes since 5.11.3:
  * None
* Tue Nov  7 2017 fabian@ritter-vogt.de
- Update to 5.11.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.3.php
- Changes since 5.11.2:
  * None
* Tue Oct 24 2017 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.2.php
- Changes since 5.11.1:
  * None
* Tue Oct 17 2017 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.1.php
- Changes since 5.11.0:
  * None
* Thu Oct  5 2017 fabian@ritter-vogt.de
- Update to 5.11.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.0.php
- Changes since 5.10.95:
  * None
* Thu Sep 14 2017 fabian@ritter-vogt.de
- Update to 5.10.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.95.php
- Changes since 5.10.5:
  * [autotests] Fix DecorationButtonTest::testPressAndHold with Qt 5.9
* Tue Aug 22 2017 fabian@ritter-vogt.de
- Update to 5.10.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.5.php
- Changes since 5.10.4:
  * None
* Tue Jul 18 2017 fabian@ritter-vogt.de
- Update to 5.10.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.4.php
- Changes since 5.10.3:
  * None
* Tue Jun 27 2017 fabian@ritter-vogt.de
- Update to 5.10.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.3.php
- Changes since 5.10.2:
  * None
* Tue Jun 13 2017 fabian@ritter-vogt.de
- Update to 5.10.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.2.php
- Changes since 5.10.1:
  * None
* Tue Jun  6 2017 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.1.php
- Changes since 5.10.0:
  * None
* Fri May 26 2017 fabian@ritter-vogt.de
- Update to 5.10.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.0.php
- Changes since 5.9.95:
  * None
* Thu May 11 2017 fabian@ritter-vogt.de
- Update to 5.9.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.95.php
- Changes since 5.9.5:
  * None
* Tue Apr 25 2017 lbeltrame@kde.org
- Update to 5.9.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.5.php
- Changes since 5.9.4:
  * None
* Tue Mar 21 2017 fabian@ritter-vogt.de
- Update to 5.9.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.4.php
- Changes since 5.9.3:
  * None
* Tue Feb 28 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.3.php
- Changes since 5.9.2:
  * None
* Tue Feb 14 2017 fabian@ritter-vogt.de
- Update to 5.9.2
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.2.php
- Changes since 5.9.1:
  * None
* Tue Feb  7 2017 fabian@ritter-vogt.de
- Update to 5.9.1
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.1.php
- Changes since 5.9.0:
  * None
* Thu Jan 26 2017 fabian@ritter-vogt.de
- Update to 5.9.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.0.php
- Changes since 5.8.95:
  * None
* Thu Jan 12 2017 fabian@ritter-vogt.de
- Update to 5.8.95 (Plasma 5.9 Beta)
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.95.php
- Changes:
  * [KDecoration] Restore application menu button.
  * Add .arcconfig.
* Tue Dec 27 2016 fabian@ritter-vogt.de
- Update to 5.8.5
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.5.php
* Wed Nov 23 2016 fabian@ritter-vogt.de
- Update to 5.8.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.4.php
* Tue Nov  1 2016 fabian@ritter-vogt.de
- Update to 5.8.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.3.php
* Tue Oct 18 2016 fabian@ritter-vogt.de
- Update to 5.8.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.2.php
* Tue Oct 11 2016 fabian@ritter-vogt.de
- Update to 5.8.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.1.php
* Wed Oct  5 2016 fabian@ritter-vogt.de
- Add Source: URL back
* Thu Sep 29 2016 fabian@ritter-vogt.de
- Update to 5.8.0
  * New LTS feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.0.php
* Thu Sep 15 2016 fabian@ritter-vogt.de
- Update to 5.7.95 (Plasma 5.8 Beta)
  * New LTS feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.95.php
* Tue Sep 13 2016 fabian@ritter-vogt.de
- Update to 5.7.5
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.5.php
* Fri Aug 26 2016 fabian@ritter-vogt.de
- Update to 5.7.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.4.php
* Tue Aug  2 2016 hrvoje.senjan@gmail.com
- Update to 5.7.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.3.php
* Wed Jul 20 2016 hrvoje.senjan@gmail.com
- Update to 5.7.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.2.php
* Wed Jul 13 2016 hrvoje.senjan@gmail.com
- Update to 5.7.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.1.php
* Thu Jun 30 2016 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.0.php
* Sun May 15 2016 hrvoje.senjan@gmail.com
- Update to 5.6.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.4.php
* Tue Apr 19 2016 hrvoje.senjan@gmail.com
- Update to 5.6.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.3.php
* Tue Apr  5 2016 hrvoje.senjan@gmail.com
- Update to 5.6.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.2.php
* Tue Mar 29 2016 hrvoje.senjan@gmail.com
- Update to 5.6.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.1.php
* Sun Mar 20 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.0.php
* Tue Mar  1 2016 hrvoje.senjan@gmail.com
- Update to 5.5.5 (boo#968966)
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.5.php
* Tue Jan 26 2016 hrvoje.senjan@gmail.com
- Update to 5.5.4:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.4.php
* Wed Jan  6 2016 hrvoje.senjan@gmail.com
- Update to 5.5.3:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.3.php
* Tue Dec 22 2015 hrvoje.senjan@gmail.com
- Update to 5.5.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.2.php
* Tue Dec 15 2015 hrvoje.senjan@gmail.com
- Update to 5.5.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.1.php
* Sat Dec 12 2015 hrvoje.senjan@gmail.com
- Update to 5.5.0:
  * For more details please see:
    https://dot.kde.org/2015/12/08/plasma-55-beautiful-new-artwork
- Move to cmake(...) BuildRequires where possible
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.4.3 (boo#955068):
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.3.php
* Sun Oct  4 2015 hrvoje.senjan@gmail.com
- Update to 5.4.2:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.2.php
* Thu Sep 10 2015 hrvoje.senjan@gmail.com
- Update to 5.4.1:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.1.php
* Mon Aug 24 2015 hrvoje.senjan@gmail.com
- Update to 5.4.0:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.0.php
* Sun Aug 16 2015 hrvoje.senjan@gmail.com
- Update to 5.3.95 aka 5.4 beta:
  This release of Plasma brings many nice touches for our users
  such as much improved high DPI support, KRunner auto-completion
  and many new beautiful Breeze icons. It also lays the ground for
  the future with a tech preview of Wayland session available.
  We're shipping a few new components such as an Audio Volume
  Plasma Widget, monitor calibration tool and the User Manager
  tool comes out beta.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.95.php
* Sun Jun 28 2015 hrvoje.senjan@gmail.com
- Update to 5.3.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.2.php
* Fri May 22 2015 hrvoje.senjan@gmail.com
- Update to 5.3.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.1.php
* Thu Apr 23 2015 hrvoje.senjan@gmail.com
- Update to 5.3 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.0.php
* Sat Apr 11 2015 hrvoje.senjan@gmail.com
- Update to 5.2.95 aka 5.3 beta:
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.95.php
- Update required Qt version to 5.4.0
* Thu Mar 19 2015 hrvoje.senjan@gmail.com
- Update to 5.2.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.2.php
* Fri Feb 20 2015 hrvoje.senjan@gmail.com
- Update to 5.2.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.1.php
* Mon Jan 26 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.0.php
* Tue Jan 13 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Beta aka 5.1.95:
  * Undo changes to Plasma desktop layout
  * Smarter sorting of results in KRunner
  * Breeze window decoration theme adds a new look to your
    desktop and is now used by default
  * New white mouse cursor theme for Breeze.
  * New plasma widgets: 15 puzzle, web browser, show desktop
  * Over 300 bugs fixed throughout Plasma modules.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.95.php
* Thu Jan  8 2015 hrvoje.senjan@gmail.com
- Activate libkdecoration2 package
